@@ -56,7 +56,7 @@ def get_synchronization_tasks(object_name):
              {'name': 'check_current_binhost',
               'message': __("Checking current binhost"),
               'essential': False,
-              'method': Object('check_current_binhost(update.cl_update_binhost)'),
+              'method': Object('check_current_binhost(update.cl_update_new_binhost)'),
               'condition': lambda GetBool, Get: (
                     not GetBool('update.cl_update_binhost_recheck_set') and
                     Get('update.cl_update_sync_rep') and
