@@ -184,11 +184,11 @@ class VariableClUpdateInnerRepList(Variable):
                 for dct in val:
                     for key, value in dct.items():
                         if key == prev_host:
-                            yield value, key.lower()
+                            yield value, key
             for dct in val:
                 for key, value in dct.items():
                     if key != prev_host:
-                        yield value, key.lower()
+                        yield value, key
         return [x for x in gen()]
 
 
@@ -199,16 +199,17 @@ class VariableClUpdateRepHosting(Variable):
 class VariableClUpdateRepHostingChoice(Variable):
     type = "choice"
     value = ''
-    opt = ["--hosting"]
+    opt = ["--repo-update"]
+    metavalue = "REPOSITORY URL"
 
     def init(self):
-        self.label = (_("Hosting name"))
-        self.help = (_("Hosting to download from"))
+        self.label = (_("Update repository"))
+        self.help = (_("Hosting to download repository from"))
 
     def choice(self):
         a = [x[1] for x in self.Get('cl_update_inner_rep_list')]
         b = self.Get('cl_update_inner_rep_list')
-        return [x[1] for x in self.Get('cl_update_inner_rep_list')]
+        return [x[1] for x in self.Get('cl_update_inner_rep_list')] or ['Default']
 
 
 class VariableClUpdateLaymanStorage(Variable):
@@ -1695,15 +1696,29 @@ class VariableClUpdateBinhostStableOptSet(Variable):
 class VariableClUpdateBinhostChoice(Variable):
     type = "choiceedit"
     value = ''
-    opt = ["--binhost"]
+    opt = ["-m", "--mirror-update"]
+    metavalue = "MIRROR_URL"
 
     def init(self):
-        self.label = _("Mirror url")
+        self.label = _("Packages mirror")
+        self.help = _("Url to download binary packages from")
 
     def choice(self):
-        return self.Get("cl_update_binhost_list")
+        return self.Get("cl_update_binhost_list") + ['auto']
 
 
+class VariableClUpdateNewBinhost(Variable):
+    def get(self):
+        if self.Get('cl_update_binhost_choice'):
+            binhost = self.Get('cl_update_binhost_choice')
+            if binhost == 'auto':
+                return self.Get('cl_update_binhost')
+            elif not binhost.startswith('https://') and not binhost.startswith('ftp://') and not binhost.startswith(
+                    'http://'):
+                binhost = f"https://{binhost}"
+            return binhost
+        return self.Get('cl_update_binhost')
+
 
 class VariableClUpdateBinhost(Variable):
     """
